Class: InertiaRails::Configuration
- Inherits:
-
Object
- Object
- InertiaRails::Configuration
- Defined in:
- lib/inertia_rails/configuration.rb
Constant Summary collapse
- DEFAULTS =
{ # Whether to combine hashes with the same keys instead of replacing them. deep_merge_shared_data: false, # Overrides Rails default rendering behavior to render using Inertia by default. default_render: false, # Allows the user to hook into the default rendering behavior and change it to fit their needs component_path_resolver: ->(path:, action:) { "#{path}/#{action}" }, # A function that transforms the props before they are sent to the client. prop_transformer: ->(props:) { props }, # DEPRECATED: Let Rails decide which layout should be used based on the # controller configuration. layout: true, # Whether to encrypt the history state in the client. encrypt_history: false, # SSR options. ssr_enabled: false, ssr_url: 'http://localhost:13714', # Used to detect version drift between server and client. version: nil, # Allows configuring the base controller for StaticController. parent_controller: '::ApplicationController', # Whether to include empty `errors` hash to the props when no errors are present. always_include_errors_hash: nil, }.freeze
- OPTION_NAMES =
DEFAULTS.keys.freeze
Class Method Summary collapse
Instance Method Summary collapse
- #bind_controller(controller) ⇒ Object
- #component_path_resolver(path:, action:) ⇒ Object
- #freeze ⇒ Object
-
#initialize(controller: nil, **attrs) ⇒ Configuration
constructor
A new instance of Configuration.
- #merge(config) ⇒ Object
- #merge!(config) ⇒ Object
- #prop_transformer(props:) ⇒ Object
-
#with_defaults(config) ⇒ Object
Internal: Finalizes the configuration for a specific controller.
Constructor Details
#initialize(controller: nil, **attrs) ⇒ Configuration
Returns a new instance of Configuration.
61 62 63 64 65 66 67 68 |
# File 'lib/inertia_rails/configuration.rb', line 61 def initialize(controller: nil, **attrs) @controller = controller @options = attrs.extract!(*OPTION_NAMES) return if attrs.empty? raise ArgumentError, "Unknown options for #{self.class}: #{attrs.keys}" end |
Class Method Details
.default ⇒ Object
42 43 44 |
# File 'lib/inertia_rails/configuration.rb', line 42 def default new(**DEFAULTS, **) end |
Instance Method Details
#bind_controller(controller) ⇒ Object
70 71 72 |
# File 'lib/inertia_rails/configuration.rb', line 70 def bind_controller(controller) Configuration.new(**@options, controller: controller) end |
#component_path_resolver(path:, action:) ⇒ Object
94 95 96 |
# File 'lib/inertia_rails/configuration.rb', line 94 def component_path_resolver(path:, action:) @options[:component_path_resolver].call(path: path, action: action) end |
#freeze ⇒ Object
74 75 76 77 |
# File 'lib/inertia_rails/configuration.rb', line 74 def freeze @options.freeze super end |
#merge(config) ⇒ Object
84 85 86 |
# File 'lib/inertia_rails/configuration.rb', line 84 def merge(config) Configuration.new(**@options, **config.) end |
#merge!(config) ⇒ Object
79 80 81 82 |
# File 'lib/inertia_rails/configuration.rb', line 79 def merge!(config) @options.merge!(config.) self end |
#prop_transformer(props:) ⇒ Object
98 99 100 |
# File 'lib/inertia_rails/configuration.rb', line 98 def prop_transformer(props:) @options[:prop_transformer].call(props: props) end |
#with_defaults(config) ⇒ Object
Internal: Finalizes the configuration for a specific controller.
89 90 91 92 |
# File 'lib/inertia_rails/configuration.rb', line 89 def with_defaults(config) @options = config..merge(@options) freeze end |