Class: InertiaRails::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/inertia_rails/configuration.rb

Constant Summary collapse

DEFAULTS =
{
  # Whether to combine hashes with the same keys instead of replacing them.
  deep_merge_shared_data: false,

  # Overrides Rails default rendering behavior to render using Inertia by default.
  default_render: false,

  # Allows the user to hook into the default rendering behavior and change it to fit their needs
  component_path_resolver: ->(path:, action:) { "#{path}/#{action}" },

  # DEPRECATED: Let Rails decide which layout should be used based on the
  # controller configuration.
  layout: true,

  # Whether to encrypt the history state in the client.
  encrypt_history: false,

  # SSR options.
  ssr_enabled: false,
  ssr_url: 'http://localhost:13714',

  # Used to detect version drift between server and client.
  version: nil,
}.freeze
OPTION_NAMES =
DEFAULTS.keys.freeze

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(controller: nil, **attrs) ⇒ Configuration

Returns a new instance of Configuration.

Raises:

  • (ArgumentError)


52
53
54
55
56
57
58
59
# File 'lib/inertia_rails/configuration.rb', line 52

def initialize(controller: nil, **attrs)
  @controller = controller
  @options = attrs.extract!(*OPTION_NAMES)

  return if attrs.empty?

  raise ArgumentError, "Unknown options for #{self.class}: #{attrs.keys}"
end

Class Method Details

.defaultObject



33
34
35
# File 'lib/inertia_rails/configuration.rb', line 33

def default
  new(**DEFAULTS, **env_options)
end

Instance Method Details

#bind_controller(controller) ⇒ Object



61
62
63
# File 'lib/inertia_rails/configuration.rb', line 61

def bind_controller(controller)
  Configuration.new(**@options, controller: controller)
end

#component_path_resolver(path:, action:) ⇒ Object



85
86
87
# File 'lib/inertia_rails/configuration.rb', line 85

def component_path_resolver(path:, action:)
  @options[:component_path_resolver].call(path: path, action: action)
end

#freezeObject



65
66
67
68
# File 'lib/inertia_rails/configuration.rb', line 65

def freeze
  @options.freeze
  super
end

#merge(config) ⇒ Object



75
76
77
# File 'lib/inertia_rails/configuration.rb', line 75

def merge(config)
  Configuration.new(**@options, **config.options)
end

#merge!(config) ⇒ Object



70
71
72
73
# File 'lib/inertia_rails/configuration.rb', line 70

def merge!(config)
  @options.merge!(config.options)
  self
end

#with_defaults(config) ⇒ Object

Internal: Finalizes the configuration for a specific controller.



80
81
82
83
# File 'lib/inertia_rails/configuration.rb', line 80

def with_defaults(config)
  @options = config.options.merge(@options)
  freeze
end